/*
 *  OrdImage example
 *
 * This Java example program requires that you execute
 * the ImageDemo.sql script prior to executing this 
 * example.  The sql script creates the table that the 
 * example operates on.   
 *
 * The example program also requires that imgdemo.dat
 * be in the same directory from which the program is 
 * run.     
 *
 */
import java.io.*;
import java.sql.*;
import oracle.sql.*;
import oracle.jdbc.driver.*;
import oracle.ord.im.*;

public class ImgDemo
{
    private String connectString = "jdbc:oracle:oci8:@";
    private String username = "scott";
    private String password = "tiger";

    private Connection conn = null;

    public static void main( String args[] )
    {
        ImgDemo demo = new ImgDemo();
        try
        {
            /* Allocate a connection */
            demo.getConnection();
 
            /* Load image data from local file and process */
            demo.doLoadProcess();
 
            /* Display image procperties and save image to local file */
            demo.doPropertiesSave();
        }
        catch ( Exception e )
        {
            e.printStackTrace( System.out );
        }
        finally
        {
            demo.freeConnection();
        }
    }

    private void getConnection() throws SQLException
    {
        DriverManager.registerDriver(new oracle.jdbc.driver.OracleDriver());
        conn = DriverManager.getConnection(connectString,username,password);
    }

    private void freeConnection()
    {
        if ( conn != null )
        {
            try
            {
                conn.close();
            }
            catch ( SQLException e )
            {
            }
            conn = null;
        }
    }

    /*
     * This example shows how to insert a row containing
     * OrdImage columns.  It then loads an image from a
     * client side file into the database.   
     * 
     * This example also demonstrates image processing.
     * Note that although the Java application object's
     * process method is called, the actual processing
     * happens on the server.
     *
     * Two examples of process occur.  First, a GIF
     * thumbnail of the image in column 2 is made and
     * stored in column 3.  Second, the image in column
     * 2 is converted to JFIF format.
     */

    private void doLoadProcess() throws SQLException, IOException
    {
        conn.setAutoCommit(false);

        Statement stmt1 = conn.createStatement();
        stmt1.executeUpdate("INSERT INTO imgdemo (id, image1, image2) VALUES" +
                      " (1, ORDSYS.ORDImage.init(), ORDSYS.ORDImage.init())");

        OracleResultSet rs = (OracleResultSet)stmt1.executeQuery(
            "SELECT image1, image2 FROM imgdemo WHERE id = 1 FOR UPDATE");
        if (rs.next())
        {
            OrdImage imgObjj1 =
                        (OrdImage)rs.getCustomDatum(1, OrdImage.getFactory());
            OrdImage imgObjj2 =
                        (OrdImage)rs.getCustomDatum(2, OrdImage.getFactory());
            imgObjj1.loadDataFromFile("imgdemo.dat");
            imgObjj1.setProperties();
            imgObjj1.processCopy("maxScale=32 32, fileFormat=GIFF", imgObjj2);
            imgObjj1.process("fileFormat=JFIF");

            OraclePreparedStatement stmt2 =
                (OraclePreparedStatement)conn.prepareStatement(
                    "UPDATE imgdemo SET image1 = ?, image2 = ? WHERE id = 1");
            stmt2.setCustomDatum(1,imgObjj1);
            stmt2.setCustomDatum(2,imgObjj2);
            stmt2.execute();
            stmt2.close();
        }
        else
        {
            throw new SQLException("row not found");
        }

        rs.close();
        stmt1.close();
        conn.commit();
    }

    /*
     * This example shows how to extract and display the properties of
     * an image.  It also demonstrates how to write an image stored in
     * the database to a local file.
     */

    private void doPropertiesSave() throws SQLException, IOException
    {
        conn.setAutoCommit(true);

        Statement stmt = conn.createStatement();
        OracleResultSet rs =
            (OracleResultSet)stmt.executeQuery(
                "SELECT image2 FROM imgdemo WHERE id = 1");
        if (rs.next())
        {
            OrdImage imgObjj =
                        (OrdImage)rs.getCustomDatum(1, OrdImage.getFactory());
            System.out.println("");
            System.out.println("Format:  " +           imgObjj.getFormat());
            System.out.println("MimeType: " +          imgObjj.getMimeType());
            System.out.println("Height: " +            imgObjj.getHeight());
            System.out.println("Width: " +             imgObjj.getWidth());
            System.out.println("ContentLength: " +     imgObjj.getContentLength());
            System.out.println("ContentFormat: " +     imgObjj.getContentFormat());
            System.out.println("CompressionFormat: " + imgObjj.getCompressionFormat());
            imgObjj.getDataInFile("image.gif");
        }
        else
        {
            throw new SQLException( "row not found" );
        }

        rs.close();
        stmt.close();
    }

}
